==> packageinstaller-pkglist_0.3.30.tar.xz: packageinstaller-pkglist/antiX_64bit_latest.pm <==
<?xml version="1.0"?>
<app>

<category>
Kernel
</category>

<name>
Kernel-antiX_64bit_latest_meltdown-patched
</name>

<description>
   <am>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</am>
   <ar>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</ar>
   <be>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</be>
   <bg>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</bg>
   <bn>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</bn>
   <ca>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</ca>
   <cs>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</cs>
   <da>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</da>
   <de>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</de>
   <el>antiX πυρήνα 64 bit Meltdown, Spectre  και Foreshadow patched LTS (5.10.27)</el>
   <en>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</en>
   <es_ES>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</es_ES>
   <es>antiX Kernel 64 bit Meltdown, Spectre y Foreshadow parcheado LTS (5.10.27)</es>
   <et>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</et>
   <eu>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</eu>
   <fa>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</fa>
   <fil_PH>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</fil_PH>
   <fi>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</fi>
   <fr_BE>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</fr_BE>
   <fr>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</fr>
   <gl_ES>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</gl_ES>
   <he_IL>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</he_IL>
   <hi>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</hi>
   <hr>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</hr>
   <hu>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</hu>
   <id>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</id>
   <is>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</is>
   <it>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</it>
   <ja>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow パッチ適用済み LTS (5.10.27)</ja>
   <kk>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</kk>
   <ko>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</ko>
   <lt>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</lt>
   <mk>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</mk>
   <mr>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</mr>
   <nb_NO>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</nb_NO>
   <nb>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</nb>
   <nl_BE>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</nl_BE>
   <nl>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</nl>
   <pl>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</pl>
   <pt_BR>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</pt_BR>
   <pt>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</pt>
   <ro>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</ro>
   <ru>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</ru>
   <sk>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</sk>
   <sl>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</sl>
   <sq>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</sq>
   <sr>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</sr>
   <sv>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</sv>
   <th>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</th>
   <tr>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</tr>
   <uk>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</uk>
   <vi>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</vi>
   <zh_CN>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</zh_CN>
   <zh_HK>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</zh_HK>
   <zh_TW>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</zh_TW>
</description>

<installable>
64
</installable>

<screenshot>none</screenshot>

<preinstall>
</preinstall>

<install_package_names>
linux-image-5.10.22-antix.1-amd64-smp
linux-headers-5.10.22-antix.1-amd64-smp
libelf-dev
libc6-dev
</install_package_names>

<postinstall>

</postinstall>

<uninstall_package_names>
linux-image-5.10.22-antix.1-amd64-smp
linux-headers-5.10.22-antix.1-amd64-smp
</uninstall_package_names>

</app>

==> packageinstaller-pkglist_0.3.32.tar.xz: packageinstaller-pkglist/antiX_64bit_latest.pm <==
<?xml version="1.0"?>
<app>

<category>
Kernel
</category>

<name>
Kernel-antiX_64bit_latest_meltdown-patched
</name>

<description>
   <am>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</am>
   <ar>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</ar>
   <be>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</be>
   <bg>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</bg>
   <bn>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</bn>
   <ca>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</ca>
   <cs>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</cs>
   <da>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</da>
   <de>antiX Kernel, 64 bit, LTS, gepatcht gegen “Meltdown”, “Spectre” und “Foreshadow” (5.10.27)</de>
   <el>antiX πυρήνα 64 bit Meltdown, Spectre  και Foreshadow patched LTS (5.10.27)</el>
   <en>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</en>
   <es_ES>antiX Kernel 64 bit Meltdown, Spectre y Foreshadow parcheado LTS (5.10.27)</es_ES>
   <es>antiX Kernel 64 bit Meltdown, Spectre y Foreshadow parcheado LTS (5.10.27)</es>
   <et>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</et>
   <eu>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</eu>
   <fa>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</fa>
   <fil_PH>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</fil_PH>
   <fi>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</fi>
   <fr_BE>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</fr_BE>
   <fr>antiX Noyau 64 bit Meltdown, Spectre and Foreshadow patché LTS (5.10.27)</fr>
   <gl_ES>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</gl_ES>
   <gu>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</gu>
   <he_IL>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</he_IL>
   <hi>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</hi>
   <hr>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</hr>
   <hu>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</hu>
   <id>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</id>
   <is>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</is>
   <it>Kernel antiX a 64 bit LTS (5.10.27) con patch per Meltdown, Spectre e Foreshadow</it>
   <ja>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow パッチ適用済み LTS (5.10.27)</ja>
   <kk>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</kk>
   <ko>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</ko>
   <lt>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</lt>
   <mk>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</mk>
   <mr>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</mr>
   <nb_NO>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</nb_NO>
   <nb>antiX-kjerne, 64 biters Meltdown, Spectre og Foreshadow-fikset, langtidsstøttet (5.10.27)</nb>
   <nl_BE>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</nl_BE>
   <nl>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</nl>
   <pl>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</pl>
   <pt_BR>Núcleo (Kernel) do antiX de 64 bits com Meltdown, Spectre e Foreshadow com patch LTS (5.10.27)</pt_BR>
   <pt>Kernel antiX 64 bit com patch para Meltdown, Spectre e Foreshadow LTS (5.10.27)</pt>
   <ro>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</ro>
   <ru>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</ru>
   <sk>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</sk>
   <sl>antiX 64 bitno jedro Meltdown, Spectre and Foreshadow zakrpano z dolgoročno podporo (5.10.27)</sl>
   <sq>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</sq>
   <sr>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</sr>
   <sv>antiX Kärna 64 bit Meltdown, Spectre och Foreshadow fixad LTS (5.10.27)</sv>
   <th>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</th>
   <tr>antiX Kernel 64 bit Meltdown, Spectre ve Foreshadow yamalı LTS (5.10.27)</tr>
   <uk>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</uk>
   <vi>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</vi>
   <zh_CN>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</zh_CN>
   <zh_HK>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</zh_HK>
   <zh_TW>antiX Kernel 64 bit Meltdown, Spectre and Foreshadow patched LTS (5.10.27)</zh_TW>
</description>

<installable>
64
</installable>

<screenshot>none</screenshot>

<preinstall>
</preinstall>

<install_package_names>
linux-image-5.10.27-antix.1-amd64-smp
linux-headers-5.10.27-antix.1-amd64-smp
libelf-dev
libc6-dev
</install_package_names>

<postinstall>

</postinstall>

<uninstall_package_names>
linux-image-5.10.27-antix.1-amd64-smp
linux-headers-5.10.27-antix.1-amd64-smp
</uninstall_package_names>

</app>
